EventHandler class

事件处理

Constructors

EventHandler({bool sync = false})
创建一个EventHandler

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
释放流控制器
listen<T>(SubscriptionHandlerMixin mixin, dynamic listen(T data), {dynamic onError(dynamic e)?}) → void
监听T类型及其子类型的事件
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
send(dynamic event) → void
发送事件
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited