ObjectHandler class
对象处理器
- Mixed-in types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
canFindObject<
T> ({String? name}) → bool -
是否能查找到对象
inherited
-
clearObjects(
) → void -
清空对象
inherited
-
dispose(
) → void -
findObject<
T> ({String? name}) → T -
查找对象
inherited
-
findObjectOrNull<
T> ({String? name}) → T? -
查找对象
inherited
-
hasObject<
T> ({String? name}) → bool -
是否有指定对象
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
putObject<
T> (T object, {String? name}) → T -
缓存对象
inherited
-
removeObject<
T> ({String? name}) → T? -
移除对象
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited