SubscriptionHandler class
订阅处理器
- Mixed-in types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addSubscription(
StreamSubscription subscription, {String? tag}) → String -
添加StreamSubscription到队列
inherited
-
clearSubscriptions(
) → void -
清空请求
inherited
-
dispose(
) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
removeSubscription(
String tag) → void -
移除指定的Index
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited