ThreadHandlerMixin mixin

线程处理混入器

Mixin applications

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clearThreads() → void
清空线程
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeThread(String tag) → void
移除线程
runDelayed(Function runnable, {Duration delay = Duration.zero, String? tag}) String
延时执行
runPeriodic(Function runnable, {required Duration duration, Duration? delay, int? count, bool condition(int)?, String? tag}) String
周期执行
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited